import React from 'react';
import ReactDOM from 'react-dom/client';
import './index.css';
import App from './App';
import reportWebVitals from './reportWebVitals';
import {Provider} from "react-redux";
import {configureStore} from "@reduxjs/toolkit";
import productsReducer from './store/services/productsSlice';
import usersReducer from './store/services/usersSlice';
import {BrowserRouter} from "react-router-dom";

const localStorageMiddleware = ({getState}) => next => action => {
    const result = next(action);
    localStorage.setItem('user', JSON.stringify(getState().usersState.user));
    return result;
};

const reHydrateStore = () => {
    if (localStorage.getItem('user') !== null) {
        return {
            usersState: {
                user: JSON.parse(localStorage.getItem('user'))
            }
        };
    }

    return undefined;
};

const store = configureStore({
    reducer: {
        usersState: usersReducer,
        productsState: productsReducer
    },
    preloadedState: reHydrateStore(),
    middleware: getDefaultMiddleware => getDefaultMiddleware().concat(localStorageMiddleware)
});

const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(
    <Provider store={store}>
        <BrowserRouter>
            <App />
        </BrowserRouter>
    </Provider>
);

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals();
